"use client";
import type {
	ICryptoInUserWalletInfo,
	ICryptoInWalletInfo,
} from "@/interfaces/crypto.interface";
import * as React from "react";

import { BuyModal } from "@/components/cryptos/buy-modal";
import { ViewModal } from "@/components/cryptos/view-modal";
import { Button } from "@/components/ui/button";
import { DataTable } from "@/components/ui/data-table";
import type { IUserWallet } from "@/interfaces/userdata.interface";
import type {
	ColumnDef,
} from "@tanstack/react-table";
import { ArrowUpDown, MoreHorizontal, Receipt } from "lucide-react";
import { useRouter } from "next/navigation";
import Link from "next/link";

interface DataTableProps<TData, TValue> {
	columns: ColumnDef<TData, TValue>[];
	data: TData[];
}

type Props = {
	walletArray: IUserWallet;
};

export function WalletTable(props: Props) {
	const router = useRouter();
	const wallet = props.walletArray.owned_cryptos;

	const columns: ColumnDef<ICryptoInUserWalletInfo, any>[] = [
		{
			accessorKey: "name",
			header: "Name",
		},
		{
			accessorKey: "value",
			header: ({ column }) => {
				return (
					<Button
						variant="light"
						onClick={() => column.toggleSorting(column.getIsSorted() === "asc")}
					>
						Value - USD
						<ArrowUpDown className="ml-2 h-4 w-4" />
					</Button>
				);
			},
		},
		{
			accessorKey: "owned_amount",
			header: ({ column }) => {
				return (
					<Button
						variant="light"
						onClick={() => column.toggleSorting(column.getIsSorted() === "asc")}
					>
						Amount owned
						<ArrowUpDown className="ml-2 h-4 w-4" />
					</Button>
				);
			},
		},
		{
			id: "actions",
			cell: ({ row }) => {
				const payment = row.original;

				return (
					<div>
						<Link href={`/sell/${row.original.id}`} className={"flex w-fit gap-2 p-2 justify-center items-center rounded hover:bg-card"}><Receipt /> <p className={"hidden sm:block"}>Sell for USD</p></Link>
					</div>
				);
			},
		},
	];

	return (
		<>
			<DataTable columns={columns} data={wallet} fieldToFilter={"name"} />
		</>
	);
}
